@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: configparser.cpp,v 1.16 2001/08/01 23:52:49 malte Exp $
+// $Id: configparser.cpp,v 1.16.2.1 2001/10/02 17:54:27 malte Exp $
 
 #include <sys/utsname.h>
 
@@ -448,9 +448,9 @@ Parser::~Parser()
 	s_self = 0;
 }
 
-QStringList Parser::availableArchs() const
+QStringList Parser::availableArchs(const QString &root) const
 {
-	QDir dir(QString::fromLatin1("%1/arch").arg(m_kernelRoot));
+	QDir dir(QString::fromLatin1("%1/arch").arg(root));
 	QStringList archs = dir.entryList(QDir::Dirs);
 	for (QStringList::Iterator it = archs.begin(); it != archs.end(); )
 	{
