@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: debAptInterface.cpp,v 1.20 2001/05/17 15:07:48 toivo Exp $ 
+//      $Id: debAptInterface.cpp,v 1.20.2.1 2001/08/18 11:01:17 binner Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -81,15 +81,15 @@ void DEBAPT::setRemote(QString remote)
 
 void DEBAPT::makeMenu(KAccel *keys, KActionCollection* act)
 {
-  updateM = new KAction( i18n("&Update"), 0, 
+  updateM = new KAction( i18n("&Update"),
 			 0, this,
 			 SLOT(updateS()), act, "debapt_update");
   updateM->plugAccel(keys);
-  upgradeM = new KAction( i18n("U&pgrade"), 0, 
+  upgradeM = new KAction( i18n("U&pgrade"),
 			  0, this,
 			  SLOT(upgradeS()), act, "debapt_upgrade");
   upgradeM->plugAccel(keys);
-  fixupM = new KAction( i18n("&Fixup"), 0, 
+  fixupM = new KAction( i18n("&Fixup"),
 			 0, this,
 			 SLOT(fixupS()), act, "debapt_fixup");
   fixupM->plugAccel(keys);
