@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: fbsdInterface.cpp,v 1.28 2001/01/14 16:44:21 toivo Exp $
+//      $Id: fbsdInterface.cpp,v 1.31 2001/05/17 15:07:48 toivo Exp $
 //
 // Author: Alex Hayward
 // xelah@ferret.lmh.ox.ac.uk
@@ -294,8 +294,9 @@ QString fbsdInterface::uninstall(int uninstallFlags, QList<packageInfo> *p, bool
   return doUninstall( uninstallFlags, packs, test);
 }
 
-QString fbsdInterface::FindFile(const QString &) {
-  return QString("");
+QStringList fbsdInterface::FindFile(const QString &) {
+  QStringList tmp;
+  return tmp;
 }
 
 bool fbsdInterface::parseName(QString name, QString *n, QString *v) {
@@ -386,7 +387,7 @@ void fbsdInterface::listPackages(QList<packageInfo> *pki) {
 	info->packageState = packageInfo::AVAILABLE;
 	info->smerge(typeID);
 	info->fixup();
-	info->update(pki, typeID, false);
+	info->pkgInsert(pki, typeID, false);
 //	pki->append(info);
       }
 
@@ -520,7 +521,7 @@ void fbsdInterface::listInstalledPackages(QList<packageInfo> *pki) {
       info->packageState = packageInfo::INSTALLED;
       info->fixup();
       //pki->append(info);
-      info->update(pki, typeID, true);
+      info->pkgInsert(pki, typeID, true);
 
       if (line != 0) line = strtok(0, "\n");
       }
@@ -676,3 +677,4 @@ bsdPortsIndexItem *bsdPortsIndexItem::find(const QString &name) {
   return 0;
 }
 
+#include "fbsdInterface.moc"
