@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////////////
-//      $Id: kpPty.cpp,v 1.14 2001/02/06 15:43:53 toivo Exp $ 
+//      $Id: kpPty.cpp,v 1.19 2001/04/15 19:42:57 bruggie Exp $ 
 // File  : kpackage.cpp
 // Author: Toivo Pedaste
 // 
@@ -40,7 +40,7 @@ kpPty::~kpPty()
 
 bool kpPty::start(bool needRoot)
 {
-  kdDebug() << "kpPty::start\n";
+  kdDebug() << "kpPty::start " << started << "\n";
   pUnterm = FALSE;
 
   if (!started && (!remote.isEmpty() || !(getuid() == 0 || !needRoot))) {
@@ -73,7 +73,7 @@ bool kpPty::start(bool needRoot)
     eventLoop = TRUE;
     kdDebug() << "Loopst\n";
     kapp->enter_loop();
-    kdDebug() << "Loopfn\n";
+    kdDebug() << "Loopfn t=" << timeout << " p=" << gotPrompt << "\n";
     tm->stop();
     if (timeout) {
       //      kdDebug() << "Start " << retList.count() <<" \n";
@@ -87,7 +87,12 @@ bool kpPty::start(bool needRoot)
 	started = TRUE;
       }
     } else {
-      started = TRUE;
+      if (!gotPrompt) {
+	started = FALSE;
+	pty->send_byte('\04');  // SU doesn't listen to ^C
+      } else {
+	started = TRUE;
+      }
     }
     return started;
   }
@@ -97,16 +102,39 @@ bool kpPty::start(bool needRoot)
 
 QStringList kpPty::run(QString cmd, bool inLoop, bool needRoot)
 {
+  bool quote = FALSE;
+  QString s;
 
   terminator.setPattern("RESULT=\\d+");
   pUnterm = FALSE;
+  gotPrompt = FALSE;
 
   if (remote.isEmpty() && !started && (getuid() == 0 || !needRoot)) {
     kdDebug() << "rRUN="<< cmd <<"\n";
     QStringList cl = QStringList::split(" ", cmd);
     QStrList cs;
     for ( QStringList::Iterator it = cl.begin(); it != cl.end(); ++it ) {
-      cs.append((*it).latin1());
+      if ((*it).find('\'') >= 0) {
+	if (quote) {     // End of quoted string
+	  s += *it;
+	  s.replace(QRegExp("'"),"");
+	  cs.append(s.latin1());
+	  //	  kdDebug() << "C=" << s << "\n";
+	  quote = FALSE;
+	} else {         // Start of quoted string
+	  s = *it;
+	  s += " ";
+	  quote = TRUE;
+	}
+      } else {
+	if (quote) {
+	  s += *it;
+	  s += " ";
+	} else {
+	  cs.append((*it).latin1());
+	  //	  kdDebug() << "Cc=" << *it << "\n";
+	}
+      }
     }
     int res = pty->run(cs.first(),cs,"dumb",FALSE);
     kdDebug() << "res="<< res <<"\n";
@@ -137,7 +165,7 @@ QStringList kpPty::run(QString cmd, bool inLoop, bool needRoot)
 void kpPty::finish(int ret)
 {
   //  int num = retList.count();
-
+  //  kdDebug() << "kpPty::finish " << ret << "\n";
   if (ret == -1) {
     QStringList::Iterator l = retList.fromLast();
     l--;
@@ -158,6 +186,12 @@ void kpPty::finish(int ret)
       retList.remove(l);                  // Remove prompt
     }
   }
+  
+  QStringList::Iterator l = retList.begin();
+  if ( l !=  retList.end()) {
+    retList.remove(l);                  // Remove command at start
+  }
+
   kdDebug() << "Ret=" << ret << "\n";
   emit result(retList,ret);
 
@@ -170,7 +204,6 @@ void kpPty::finish(int ret)
 void kpPty::block_in(const char* txt, int len)
 {
   bool unterm = FALSE;
-  //  kdDebug() << "L=" << len << "\n";
 
   if (len < 0) len = 0;
   QCString text( txt, len+1 );
@@ -179,6 +212,8 @@ void kpPty::block_in(const char* txt, int len)
     unterm = TRUE;
   }
 
+  //   kdDebug() << "L=" << text << "\n";
+
   QString stext =  QString::fromLocal8Bit(text);
 
   emit textIn(stext);
@@ -221,12 +256,14 @@ void kpPty::block_in(const char* txt, int len)
     //    kdDebug() << "s=[" << text << "]\n";
     
     for ( QStringList::Iterator it = sl.begin(); it != sl.end(); ++it ) {
+      //      kdDebug() << "L=" << *it << "\n";
       retList << (*it);
     }
   }
   pUnterm = unterm;
 
   if (stext.right(2) == "# ") {
+    gotPrompt = TRUE;
     emit textIn("\r \n");
     finish(-1);
   }
@@ -253,3 +290,4 @@ void kpPty::slotTimeout()
     kapp->exit_loop();
   }
 }
+#include "kpPty.moc"
