@@ -1,6 +1,6 @@
 
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: packageInfo.cpp,v 1.25 2000/12/05 13:51:40 toivo Exp $
+// $Id: packageInfo.cpp,v 1.28 2001/07/20 14:55:35 toivo Exp $
 // File  : packageInfo.cpp
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -217,9 +217,11 @@ int packageInfo::pnewer(QString s, QString sp)
 {
   int ns = 0, nsp = 0, vs, vsp;
 
+  //  kdDebug() << "S=" << s  << " SP=" << sp  << "\n";
   while (TRUE) {
     vs = getDigElement(s,&ns);
     vsp = getDigElement(sp,&nsp);
+    //    kdDebug() << "s=" << ns << " " << vs << " sp=" << nsp << " " << vsp << "\n";
     if (vs < 0 && vsp < 0)
       return 0;
     if (vs < 0 && vsp < 0)
@@ -233,13 +235,22 @@ int packageInfo::pnewer(QString s, QString sp)
 
     QString svs = getNdigElement(s,&ns);
     QString svsp = getNdigElement(sp,&nsp);
+    //    kdDebug() << "vs=" << ns << " " << svs << " sp=" << nsp << " " << svsp << "\n";
     if (svs == "" && svsp == "")
       return 0;
     if (svs == "" && svsp != "")
       return 1;
     if (svs != "" && svsp == "")
       return -1;
+
+    if (svsp.isNull()) { // Allow for QT strangeness comparing null string
+      svsp = "";
+    }
+    if (svs.isNull()) {
+      svs = "";
+    }
     int n = svsp.compare(svs);
+    //    kdDebug() << "svsp=" << svsp << "=" << svsp.length() <<  " svs=" << svs << "=" <<svs.length() <<  " n=" << n << "\n";
     if (n != 0)
       return n;
   }
@@ -292,8 +303,10 @@ int packageInfo::newer(packageInfo *p)
     hisVersion = s;
   }
 
-  //printf("s:%s=%s,i:%s=%s,f:%s=%s\n",
-  //  ss.data(),ssp.data(),is.data(),isp.data(),fs.data(),fsp.data());
+  //  kdDebug() << "mySerial=" <<  mySerial << " hisSerial=" <<  hisSerial <<"\n";
+  //  kdDebug() << "myVersion=" <<  myVersion << " hisVersion=" <<  hisVersion <<"\n";
+  //  kdDebug() << "myRelease=" <<  myRelease << " hisRelease=" <<  hisRelease <<"\n";
+
   int n =  pnewer(mySerial,hisSerial);
   if (n)
     return n;
@@ -338,7 +351,7 @@ KPLVItem *packageInfo::place(KPQListView *tree, bool insertI)
   bool doit = FALSE;
 
   doit = TRUE;
-  if (packageState == NOLIST)
+  if (packageState == NOLIST || packageState == HIDDEN)
     doit = FALSE;
 
   if (doit) {
@@ -462,9 +475,22 @@ bool packageInfo::smerge( const QString &exp) {
   return FALSE;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+void packageInfo::pkgFileIns(QString fileName)
+{
+  if (pkgInsert(kpackage->management->allPackages, interface->typeID, FALSE)) {
+    packageState = packageInfo::NEW;
+    place(kpackage->management->treeList,TRUE);
+    info->insert("filename", new QString(fileName));
+    info->insert("base", new QString(""));
+
+    QString pname = getProperty("name") + interface->typeID;
+    kpackage->management->dirUninstPackages->insert(pname,this);
+  }
+}
 
 //////////////////////////////////////////////////////////////////////////////
-bool packageInfo::update(QList<packageInfo> *pki, const QString &exp,
+bool packageInfo::pkgInsert(QList<packageInfo> *pki, const QString &exp,
 			 bool installed, bool infoPackage)
 {
   QDict<packageInfo> *dirInstPackages = kpackage->management->dirInstPackages;
@@ -475,19 +501,28 @@ bool packageInfo::update(QList<packageInfo> *pki, const QString &exp,
   //  printf("U1=%s\n",pname.data());
 
   bool shouldUpdate = TRUE;
+  bool hidden = FALSE;
 
   packageInfo *pi = dirInstPackages->find(pname);
+  if (pi) { // installed version exists
+    if ((pi->packageState != BAD_INSTALL)
+	&& (pi->packageState != NOLIST))  {
+      if (newer(pi) >= 0) {
+	hidden = TRUE;
+      }
+    }
+  }
 
-  if (pi && (newer(pi) >= 0)
-      && (pi->packageState != BAD_INSTALL)
-      && (pi->packageState != NOLIST))  {
-    shouldUpdate = FALSE;
-  } else {
-    packageInfo *pu = dirUninstPackages->find(pname);
-    if (pu && (newer(pu) >= 0)
-	&& (pu->packageState != BAD_INSTALL)
+  packageInfo *pu = dirUninstPackages->find(pname);
+  if (pu) { // available version exists
+    if ((pu->packageState != BAD_INSTALL)
 	&& (pu->packageState != NOLIST))  {
-      shouldUpdate = FALSE;
+      if (newer(pu) >= 0) {
+	shouldUpdate = FALSE;
+      } else if (!installed) { // If older available package exists, remove it
+	dirUninstPackages->remove(*(pu->info->find("name")));
+	pki->remove(pu);
+      }
     }
   }
 
@@ -499,29 +534,31 @@ bool packageInfo::update(QList<packageInfo> *pki, const QString &exp,
     if (packageState != BAD_INSTALL) {
       if (installed)
 	packageState = INSTALLED;
-      else if (pi) {
-	QString version = pi->getProperty("version");
-	if (version.isEmpty()) {
-	  if (pi->packageState == NOLIST)
-	    packageState = NEW;
-	  else
-	    packageState = UPDATED;
+      else if (pi) { // installed version exists
+	if (hidden) {
+	  packageState = HIDDEN;
 	} else {
-	  packageState = UPDATED;
-	  if (pi->hasProperty("old-version"))
-          {
-	    info->insert("old-version",
-                         new QString(pi->getProperty("old-version")));
-	  } else { 
-	    info->insert("old-version",new QString(version));
-          }
-	  QString group = getProperty("group");
-	  if (group == "NEW") {
-	    if (pi->hasProperty("group"))
-	    {
-	      info->replace("group",
-                            new QString(pi->getProperty("group")) );
-            }
+	  QString version = pi->getProperty("version");
+	  if (version.isEmpty()) {
+	    if (pi->packageState == NOLIST)
+	      packageState = NEW;
+	    else
+	      packageState = UPDATED;
+	  } else {
+	    packageState = UPDATED;
+	    if (pi->hasProperty("old-version")) {
+	      info->insert("old-version",
+			   new QString(pi->getProperty("old-version")));
+	    } else { 
+	      info->insert("old-version",new QString(version));
+	    }
+	    QString group = getProperty("group");
+	    if (group == "NEW") {
+	      if (pi->hasProperty("group")) {
+		info->replace("group",
+			      new QString(pi->getProperty("group")) );
+	      }
+	    }
 	  }
 	}
       } else
@@ -537,8 +574,9 @@ bool packageInfo::update(QList<packageInfo> *pki, const QString &exp,
     } else
       dirUninstPackages->insert(pname,this);
     return TRUE;
-  } else
+  } else {
     return FALSE;
+  }
 }
 
 //////////////////////////////////////////////////////////////////////////////
