@@ -1,4 +1,4 @@
-/* 	$Id: rpmMessages.h,v 1.7 1999/10/22 16:02:01 toivo Exp $	 */
+/* 	$Id: rpmMessages.h,v 1.9 2000/08/04 15:54:31 toivo Exp $	 */
 #ifndef H_MESSAGES
 #define H_MESSAGES
 
@@ -8,14 +8,12 @@
 extern "C" {
 #endif
 
-#  if RPM_V1 >= 3 && RPM_V2 == 0 && RPM_V3 >= 1
-
-#else
+#if RPM_V1 == 3 && RPM_V2 == 0 && RPM_V3 < 1
  void rpmMessage(int level, char * format, ...);
 #endif                                                                                                       
  void rpmMess(char *buff);
  void rpmBuff(char *buff);
- void rpmErr();
+ void rpmErr(void);
 #ifdef __cplusplus 
 }
 #endif
