@@ -33,10 +33,18 @@ static int verifyHeader(const char * prefix, Header h, int verifyFlags,
     int type; // need with some versions of RPM
     const char ** fileList;
     int count;
+#if RPM_V1 < 4 || (RPM_V1 == 4 && RPM_V2 == 0 && RPM_V3 < 3)
     int verifyResult;
+#else
+    rpmVerifyAttrs verifyResult;
+#endif
     int i, ec, rc;
     int_32 * fileFlagsList;
+#if RPM_V1 < 4 || (RPM_V1 == 4 && RPM_V2 == 0 && RPM_V3 < 3)
     int omitMask = 0;
+#else
+    rpmVerifyAttrs omitMask = RPMVERIFY_NONE;
+#endif
     int enumber = 0;
     QString buff, errors;
  
@@ -133,7 +141,11 @@ static int verifyHeader(const char * prefix, Header h, int verifyFlags,
 
 static int verifyDependencies(rpmdb db, Header h, QStringList &list) {
     rpmTransactionSet rpmdep;
+#if RPM_V1 < 4 || (RPM_V1 == 4 && RPM_V2 == 0 && RPM_V3 < 3)
     struct rpmDependencyConflict * conflicts;
+#else
+    rpmDependencyConflict conflicts;
+#endif
     int numConflicts;
     const char * name, * version, * release;
     int type, count, i;
