@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: slackInterface.h,v 1.15 2001/01/14 16:44:21 toivo Exp $ 
+//      $Id: slackInterface.h,v 1.17 2001/04/03 16:17:53 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -13,7 +13,6 @@
 #include <qlist.h>
 #include <kprocess.h>
 
-#include "procbuf.h"
 #include "pkgInterface.h"
 
 class packageInfo;
@@ -34,7 +33,7 @@ public:
 			      const QString &version);
   QStringList getFileList(packageInfo *p);
 
-  QString FindFile(const QString &name);
+  QStringList FindFile(const QString &name);
   bool parseName(QString name, QString *n, QString *v);
 
   QString install(int installFlags, QList<packageInfo> *plist, bool &test);
