@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: utils.h,v 1.3 2000/05/02 15:01:39 toivo Exp $ 
+//      $Id: utils.h,v 1.4 2000/06/11 15:18:15 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -9,7 +9,6 @@
 
 class KPLVItem;
 
-char *getGroup(char **gs);
-KPLVItem *findGroup(char *name, KPLVItem *search);
+KPLVItem *findGroup(QString ame, KPLVItem *search);
 
 
