@@ -14,19 +14,20 @@
  *                                                                         *
  ***************************************************************************/
 
-#pragma implementation
-
 // Trash Can
 
 #include <qtooltip.h>
 #include <qlabel.h>
 #include <qpainter.h>
+
 #include <kapp.h>
 #include <kiconloader.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kstddirs.h>
+
 #include "ksvdraglist.h"
+#include "ksvdrag.h"
 #include "ActionList.h"
 #include "trash.h"
 
@@ -39,15 +40,16 @@ KSVTrash::KSVTrash (QWidget* parent, const char* name)
   setLineWidth(1);
   setMidLineWidth(0);
 
-  setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
+  setFrameStyle (QFrame::StyledPanel | QFrame::Sunken);
 
   mLabel->setPixmap(mKIL->loadIcon("trashcan_empty", KIcon::Desktop));
-  mLabel->setGeometry(5, 7, 32, 32);
+  mPixmapWidth = mLabel->pixmap()->width();
+  mLabel->setGeometry(5, 7, mPixmapWidth, mPixmapWidth);
 
   QToolTip::add(mLabel, i18n("Drag here to remove services"));
   QToolTip::add(this, i18n("Drag here to remove services"));
-     
-  setMinimumSize(42, 44);
+    
+  setMinimumSize(sizeHint());
   setAcceptDrops(true);
 
   mLabel->installEventFilter(this);
@@ -82,7 +84,8 @@ void KSVTrash::dropEvent (QDropEvent* e)
 
 void KSVTrash::dragMoveEvent ( QDragMoveEvent* e )
 {
-  if (e->provides ("application/x-ksysv") && e->source() && strcmp (e->source()->name(), "Scripts"))
+  if (e->provides ("application/x-ksysv") &&
+      e->source() && strcmp (e->source()->name(), "Scripts"))
     {
       QPainter p;
 	  
@@ -132,5 +135,9 @@ bool KSVTrash::eventFilter( QObject *, QEvent *e )
 
 QSize KSVTrash::sizeHint() const
 {
-  return QSize (42, 44);
+  static QSize size = QSize (mPixmapWidth + 2 * 5, mPixmapWidth + 2 * 7);
+
+  return size;
 }
+
+#include "trash.moc"
