@@ -1,6 +1,6 @@
 #include "misc.h"
 #include "kerror.h"
-#include <qmessagebox.h>
+#include <kmessagebox.h>
 
 KError::KError() {
 }
@@ -15,8 +15,7 @@ void KError::addMsg(QString amsg) {
 
 void KError::display() {
   for (uint i=0;i<msgs.count();i++)
-     QMessageBox::information(0, i18n("Message"),
-       msgs[i], i18n("OK"));
+     KMessageBox::information(0, msgs[i]);
   msgs.clear();
 }
 
