@@ -17,15 +17,15 @@
 #include "misc.h"
 #include "mainWidget.h"
 
-static const char *description = 
-	I18N_NOOP("KDE User editor");
+static const char *description =
+	I18N_NOOP("KDE User Editor");
 
 char tmp[1024];
 KConfig *config;
 KError *err;
 bool changed = false;
 
-KUserGlobals *kug = NULL;
+KUserGlobals *kug = 0;
 
 #ifdef _KU_QUOTA
 int is_quota = 1;
@@ -33,7 +33,7 @@ int is_quota = 1;
 int is_quota = 0;
 #endif
 
-#ifdef _KU_SHADOW
+#ifdef HAVE_SHADOW
 int is_shadow = 1;
 #else
 int is_shadow = 0;
@@ -56,7 +56,7 @@ int main(int argc, char **argv) {
   aboutData.addAuthor("Denis Perchine", I18N_NOOP("kuser author"),
     "dyp@perchine.com", "http://www.perchine.com/dyp/");
   KCmdLineArgs::init(argc, argv, &aboutData);
-  mainWidget *mw = NULL;
+  mainWidget *mw = 0;
 
   KApplication a;
 
