@@ -66,7 +66,7 @@ void InputFileCtl::selectPressed()
 
                 if( !url.isLocalFile() )
 		{
-		  KMessageBox::sorry( 0L, i18n( "Only local files are supported yet." ) );
+		  KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
 		  return;
 		}
 
