@@ -9,6 +9,8 @@
 #include <fcntl.h>
 #include <fstream>
 
+using namespace std;
+
 bool liloimage::isLinux() const {
 	const_iterator it=begin();
 	if((*it).contains("image"))
@@ -112,9 +114,9 @@ bool liloconf::install(bool probeonly)
 	f.close();
 
 	if(probeonly)
-		command.sprintf("lilo -v -t -C %s 2>&1", (char const * const)lilotmp);
+		command.sprintf("/sbin/lilo -v -t -C %s 2>&1", (char const * const)lilotmp);
 	else
-		command.sprintf("lilo -v -C %s 2>&1", (char const * const)lilotmp);
+		command.sprintf("/sbin/lilo -v -C %s 2>&1", (char const * const)lilotmp);
 	output="";
 	FILE *lilo=popen(command, "r");
 	char *buf=(char *) malloc(1024);
@@ -197,8 +199,15 @@ bool liloconf::probe()
 		}
 		String version=(*it).regex("(test-?|pre-?)?(([0-9]+(\\.|-)?(test-?|pre-?|ac-?|bero-?)?)+[0-9]+)+(smp|BOOT|enterprise)?");
 		String label=version;
-		if(version.empty()) // Yuck - not a Red Hat Linux kernel
+		if(version.empty()) // Yippie! - not a Red Hat Linux kernel
 			version="linux";
+		
+		if (label.empty())
+		{
+			label = (*it);
+			if (label.find('/') >= 0)
+				label = label.right(label.length()-1-label.rfind('/'));
+		}	
 		// Check if we have an initial ramdisk (initrd) for this kernel...
 		String initrd;
 		if((*it).contains("vmlinuz"))
@@ -220,13 +229,13 @@ bool liloconf::probe()
 				label=label.replace("enterprise", "E");
 		if(label.size()>15)
 			label=label.left(15);
-		
+
 		// label, kernel, root, initrd, optional, append, vga, readonly,
 		// literal, ramdisk
 		addLinux(label, *it, root, initrd);
 	}
 	addLinux("Linux_Compiled", "/usr/src/linux/arch/i386/boot/bzImage", root, "", true); // User-compiled kernel that wasn't moved...
-	
+
 	// Scan for other OSes... and Linux kernels on other partitions.
 	for(StringList::iterator it=p.partition.begin(); it!=p.partition.end(); it++) {
 		switch(p.id[*it]) {
@@ -249,7 +258,7 @@ bool liloconf::probe()
 		case 0xc4: // DRDOS/sec
 		case 0xc6: // DRDOS/sec
 		{
-			// Try to determine which type of DOS we're using	
+			// Try to determine which type of DOS we're using
 			String mp=p.mountpt[*it];
 			String lbl="DOS";
 			if(mp.empty()) {
@@ -449,7 +458,7 @@ StringList const &liloconf::entries() const
 			lbl=lbl.mid(2);
 		while(isspace(lbl.right().chr(0)) || lbl.right()==(String)"\"")
 			lbl=lbl.left(lbl.size()-1);
-		s->add(lbl);		
+		s->add(lbl);
 	}
 	return *s;
 }
@@ -461,7 +470,8 @@ String const liloconf::dflt() const
 			dflt=(*it).simplifyWhiteSpace();
 	if(dflt.empty()) {
 		liloimages::const_iterator it=images.begin();
-		dflt=(*it).grep("^[ \t]*label[ \t]*=").simplifyWhiteSpace();
+		if (it != images.end())
+			dflt=(*it).grep("^[ \t]*label[ \t]*=").simplifyWhiteSpace();
 	}
 	if(!dflt.empty()) {
 		dflt=dflt.mid(dflt.locate("=")+2).simplifyWhiteSpace();
